#include <TinyDebugSerial.h>
#include "tiny_IRremote.h"
#include "FastLED.h"

#define LED_COUNT 6
CRGB leds[LED_COUNT];
const uint8_t datapin = 0;
const uint8_t clockpin = 2;

const uint8_t remotepin = 4;
IRrecv irrecv(remotepin);
decode_results results;

TinyDebugSerial serial = TinyDebugSerial();

uint8_t count = 0;
uint8_t color = 120;
uint8_t saturation = 255;
uint8_t value = 30;


void setup() {
  OSCCAL += 1; // User calibration

  FastLED.addLeds<APA102, datapin, clockpin>(leds, LED_COUNT);
  FastLED.show();

  irrecv.enableIRIn(); // Start the receiver

  serial.begin(9600);
  serial.println("Hi from ATTINY!");
}

void loop() {
  _delay_ms(25);
  if (irrecv.decode(&results)) {
    irrecv.resume(); // Receive the next value
    serial.print("RECEIVED ");
    serial.print(results.decode_type, DEC);
    serial.print(" ");
    serial.println(results.value, HEX);

    switch (results.value) {
      case 0x490: // TV-Vol+
        value = value + 2;
        break;
      case 0xC90: // TV-Vol-
        value = value - 2;
        break;
      case 0x90: // TV-CH+
        color = color + 8;
        break;
      case 0x890: // TV-CH-
        color = color - 8;
        break;
      case 0x170D: // -
        saturation = saturation + 10;
        break;
      case 0x570D: // +
        saturation = saturation - 10;
        break;

      default:
        color = 0;
        saturation = 255;
        value = 0;
        break;
    }

    CRGB chosen;
    chosen = CHSV(color, saturation, value);

    for (uint8_t i = 0; i < LED_COUNT; i++) {
      leds[i] = chosen;
    }
    
    FastLED.show();
  }
}

